@@ -8,7 +8,7 @@ JDBIx - Object-oriented higher-level DBI interface for select into arrays, place
 
 		Jim Turner
 		
-		Email: jim.turner@lmco.com
+		Email: turnerjw784@yahoo.com
 
 	All rights reserved.
 
@@ -18,139 +18,108 @@ file.
 
 =head1 SYNOPSIS
 
-#!/usr/bin/perl
+	#!/usr/bin/perl
 
-use strict;
+	use strict;
+	use JDBIx;
 
-use JDBIx;
+	&jdbix_setlog('/tmp/dbixlogt.txt');   #OPTIONALLY, SET UP A LOG FILE.
 
-B<&jdbix_setlog>('/tmp/dbixlogt.txt');   #OPTIONALLY, SET UP A LOG FILE.
+	#CONNECT TO A DATABASE:
 
-#CONNECT TO A DATABASE:
+	my $dbh = new JDBIx('dbtype:dbname,dbuser,dbpswd',{}) 
+			or die ("-no login: err=" . &jdbix_err() . ':' . &jdbix_errstr . "=\n");
 
-my $dB = B<new JDBIx>('I<dbtype>:I<dbname>,I<dbuser>,I<dbpswd>',{}) 
-		or die ("-no login: err=" . B<&jdbix_err>() . ':' . B<&jdbix_errstr> . "=\n");
+	$dbh->package(__PACKAGE__);  #UNLESS PACKAGE IS "main::".
 
-$dB->B<package>(__PACKAGE__);  #UNLESS PACKAGE IS "main::".
+	#DO A SIMPLE SELECT, STORING THE RESULTS INTO @f1 AND @f2.
 
-#DO A SIMPLE SELECT, STORING THE RESULTS INTO @f1 AND @f2.
-
-our (@f1, @f2);  #MUST BE PACKAGE, NOT "MY" VARIABLES:
-
-my $res = $dB->B<select>('I<select field1, field2 into :f1, :f2 from test>') 
-		or warn ('Could not do select (' . $dB->B<err>() . '.' . $dB->B<errstr>() . ')!');
-
-for (my $i=0;$i<=$res;$i++) {
-
-	print "-For record# $i: field1=$f1[$i], field2=$f2[$i]\n";
-
-}
-
-#ANOTHER SIMPLE SELECT, RETURNING THE RESULTS INTO @res:
-
-my @res = $dB->B<select>('I<select field1, field2 from test'>);
-
-for (my $i=0;$i<=$#res;$i++) {
-
-        print "\n-For record# $i: ";
-
-        for (my $j=0;$j<=$#{$res[$i]};$j++) {
-
-                print "value =$res[$i]->[$j],\t";
-
-        }
-
-}
-
-#DO A VECTORIZED SELECT, SELECTING A RECORD FOR EACH KEY VALUE IN @f1:
-
-our (@f3, @f4);  #MUST BE PACKAGE, NOT "MY" VARIABLES:
-
-my $sqlstr = 'select field3, field4 into :f3, :f4 from test2 where field1 = :f1';
-
-$res = $dB->B<do>(I<$sqlstr>, I<1>) or die $dB->errstr();
-
-#INSERT A NEW RECORD:
-
-$res = $dB->B<do1>('I<insert into test values (?, ?, ?, ?)>', 
-		'I<value1>', 'I<value2>', 'I<value3>', 'I<value4>') or 
-	die ('Could not insert record (' . $dB->B<err>() . '.' . $dB->B<errstr>() . ')!');
-
-#COMMIT THE TRANSACTION:
-
-$dB->B<commit>();
-
-#FETCH THE AUTONUMBER / SEQUENCE KEY VALUE OF THE LAST INSERT:
-
-my $newestkey = $dB->B<fetchseq>('I<keyfieldname>');
-
-print "..Just inserted new record with key: $newestkey.\n";
-
-#CURSORS:
-
-$sqlstr = 'update test set field1 = ? where field2 = ?';
-
-my $csr = $dB->B<opencsr>($sqlstr) or die ("Could not open ($sqlstr) (".$dB->B<errstr>().")!");
-
-#AN OPTIONAL 2ND ARGUMENT TO I<opencsr> CAUSES $dbh->execute() TO BE CALLED 
-IN ADDITION TO $dbh->prepare().  IF THE RETURN VARIABLE IS A LIST, A 
-SECOND VALUE IS RETURNED REPRESENTING THE RESULT RETURNED BY $dbh->execute. 
-ALSO, IF USED FOR A SELECT STATEMENT, VARIABLES CAN BE BOUND JUST AS 
-FOR select (see ":f1" and ":f2" in prev. examples). 
-
-for (my $i=0;$i<=$#f1;$i++) {
-
-	$csr->bind($i, $f1[$i]);
-
-}
-
-$csr->B<closecsr>();
-
-#AN EXAMPLE OF SELECT USING CURSORS:
-
-$sqlstr = 'select field3, field4 from test2 where field1 = ?';
-
-$csr = $dB->B<opencsr>($sqlstr) or die "Could not open ($sqlstr) (".$dB->B<errstr>().")!";
-
-for (my $i=0;$i<=$#f1;$i++) {
-
-	$csr->bind($f1[$i]);
-
-	while (my ($f3, $f4) = $csr->fetch()) {
-
-		print "-For record# $i (key $f1[$i]): field3=$f3, field4=$f4\n";
+	our (@f1, @f2);  #MUST BE PACKAGE, NOT "MY" VARIABLES:
+	my $res = $dbh->select('select field1, field2 into :f1, :f2 from test') 
+			or warn ('Could not do select (' . $dbh->err() . '.' . $dbh->errstr() . ')!');
 
+	for (my $i=0;$i<=$res;$i++) {
+		print "-For record# $i: field1=$f1[$i], field2=$f2[$i]\n";
 	}
 
-}
-
-$csr->B<closecsr>();
-
-#ANOTHER EXAMPLE OF VECTOR SELECT USING CURSORS (WITH INTO CLAUSE):
-#NOTE:  $csr->fetch() and $csr->fetchall() WILL NOT RETURN RESULTS HERE BECAUSE 
-#THE DATA HAS ALREADY BEEN FETCHED BY THE $csr->bind() CALL INTO THE VECTORS: @f1 and @f3!
-
-$sqlstr = 'select field3, field4 into :f3, :f4 from test2 where field1 = ?';
-
-$csr = $dB->B<opencsr>($sqlstr) or die "Could not open ($sqlstr) (".$dB->B<errstr>().")!";
-
-for (my $i=0;$i<=$#f1;$i++) {
-
-	$res = $csr->bind($f1[$i]);
-
-	for (my $j=0;$j<$res;$j++) {
-
-		print "-For record# $i (key $f1[$i]): field3=$f3[$j], field4=$f4[$j]\n";
+	#ANOTHER SIMPLE SELECT, RETURNING THE RESULTS INTO @res:
 
+	my @res = $dbh->select('select field1, field2 from test');
+	for (my $i=0;$i<=$#res;$i++) {
+		print "\n-For record# $i: ";
+		for (my $j=0;$j<=$#{$res[$i]};$j++) {
+			print "value =$res[$i]->[$j],\t";
+		}
 	}
 
-}
+	#DO A VECTORIZED SELECT, SELECTING A RECORD FOR EACH KEY VALUE IN @f1:
 
-$csr->B<closecsr>();
+	our (@f3, @f4);  #MUST BE PACKAGE, NOT "MY" VARIABLES:
+	my $sqlstr = 'select field3, field4 into :f3, :f4 from test2 where field1 = :f1';
+	$res = $dbh->do($sqlstr, 1) or die $dbh->errstr();
 
-#DISCONNECT FROM THE DATABASE:
+	#INSERT A NEW RECORD:
 
-$dB->B<disconnect>();
+	$res = $dbh->do1('insert into test values (?, ?, ?, ?)', 
+			'value1', 'value2', 'value3', 'value4') 
+		or die ('Could not insert record (' . $dbh->err() . '.' . $dbh->errstr() . ')!');
+
+	#COMMIT THE TRANSACTION:
+
+	$dbh->commit();
+
+	#FETCH THE AUTONUMBER / SEQUENCE KEY VALUE OF THE LAST INSERT:
+
+	my $newestkey = $dbh->fetchseq('keyfieldname');
+	print "..Just inserted new record with key: $newestkey.\n";
+
+	#CURSORS:
+
+	$sqlstr = 'update test set field1 = ? where field2 = ?';
+	my $csr = $dbh->opencsr($sqlstr) or die ("Could not open ($sqlstr) (".$dbh->errstr().")!");
+
+	#AN OPTIONAL 2ND ARGUMENT TO opencsr CAUSES $dbh->execute() TO BE CALLED 
+	#IN ADDITION TO $dbh->prepare().  IF THE RETURN VARIABLE IS A LIST, A 
+	#SECOND VALUE IS RETURNED REPRESENTING THE RESULT RETURNED BY $dbh->execute. 
+	#ALSO, IF USED FOR A SELECT STATEMENT, VARIABLES CAN BE BOUND JUST AS 
+	#FOR select (see ":f1" and ":f2" in prev. examples). 
+
+	for (my $i=0;$i<=$#f1;$i++) {
+		$csr->bind($i, $f1[$i]);
+	}
+	$csr->closecsr();
+
+	#AN EXAMPLE OF SELECT USING CURSORS:
+
+	$sqlstr = 'select field3, field4 from test2 where field1 = ?';
+	$csr = $dbh->opencsr($sqlstr) or die "Could not open ($sqlstr) (".$dbh->errstr().")!";
+	for (my $i=0;$i<=$#f1;$i++) {
+		$csr->bind($f1[$i]);
+		while (my ($f3, $f4) = $csr->fetch()) {
+			print "-For record# $i (key $f1[$i]): field3=$f3, field4=$f4\n";
+		}
+	}
+	$csr->closecsr();
+
+	#ANOTHER EXAMPLE OF VECTOR SELECT USING CURSORS (WITH INTO CLAUSE):
+	#NOTE:  $csr->fetch() and $csr->fetchall() WILL NOT RETURN RESULTS HERE BECAUSE 
+	#THE DATA HAS ALREADY BEEN FETCHED BY THE $csr->bind() CALL INTO THE VECTORS: @f1 and @f3!
+
+	$sqlstr = 'select field3, field4 into :f3, :f4 from test2 where field1 = ?';
+	$csr = $dbh->opencsr($sqlstr) or die "Could not open ($sqlstr) (".$dbh->errstr().")!";
+	for (my $i=0;$i<=$#f1;$i++) {
+		$res = $csr->bind($f1[$i]);
+		for (my $j=0;$j<$res;$j++) {
+			print "-For record# $i (key $f1[$i]): field3=$f3[$j], field4=$f4[$j]\n";
+		}
+	}
+	$csr->closecsr();
+
+	#DISCONNECT FROM THE DATABASE:
+
+	$dbh->disconnect();
+
+	exit(0);
 
 =head1 DESCRIPTION
 
@@ -167,13 +136,13 @@ Another feature is abstraction of sequence / autonumbering fields in a database-
 
 =over 4
 
-=item $dB = B<new JDBIx>(I<connect-string>, [ I<attrs> ]);
+=item $dbh = B<new JDBIx>(I<connect-string>, [ I<attrs> ]);
 
-Creates a new database connection object. I<connect-string> normally contains the DBD::I<modulename>, 
-the I<database-name>, the I<user-name>, and the I<password> in the format:  
+Creates and returns a new database connection object. I<connect-string> normally contains the 
+DBD::I<modulename>, the I<database-name>, the I<user-name>, and the I<password> in the format:  
 'I<modulename>:I<database-name>,I<user-name>,I<password>'.  The I<user-name>, and I<password> 
 are sometimes optional depending on the database and connection requirements.  I<attrs> is 
-an optional hash-reference and DBD::I<modulename> -dependent.
+an optional hash-reference and DBD::I<modulename> -dependent.  Returns I<undef> on failure.
 
 I<connect-string>:  Examples:
 
@@ -211,7 +180,7 @@ If an argument is passed, then sets the default I<autocommit> status for any fut
 created within the program to on or off based on that argument, if no argument is passed, it returns 
 the current default I<autocommit> status, which is zero (0) if this function has not been previously 
 called with an argument.  NOTE:  It does not alter the I<autocommit> flag for any currently opened 
-database objects, see $dB->B<autocommit>() for changing the I<autocommit> flag for a currently opened 
+database objects, see $dbh->B<autocommit>() for changing the I<autocommit> flag for a currently opened 
 database.
 
 =item I<$scalar> = B<&jdbix_err>([ I<$database_object> ]);
@@ -220,7 +189,7 @@ Returns the last error code number encountered.  If I<$database_object> is speci
 the last error code recorded for that database object, otherwise $DBI::err is returned.  NOTE:  this 
 method can be used after an I<attempted> creation of a new database object to get the error code 
 when the object fails to be created (and there's thus no database object).  After a database object 
-is successfully created, it's preferred to use $db->B<err>().
+is successfully created, it's preferred to use $dbh->B<err>().
 
 =item I<$scalar> = B<&jdbix_errstr>([ I<$database_object> ]);
 
@@ -229,9 +198,9 @@ specified, then it returns the last error message recorded for that database obj
 $DBI::errstr is returned.  NOTE:  this method can be used after an I<attempted> creation of a new 
 database object to get the error code when the object fails to be created (and there's thus no 
 database object).  After a database object is successfully created, it's preferred to use 
-$db->B<errstr>().
+$dbh->B<errstr>().
 
-=item $dB->B<setlog>(I<log-file>); -or- B<jdbix_setlog>(I<log-file>);
+=item $dbh->B<setlog>(I<log-file>); -or- B<jdbix_setlog>(I<log-file>);
 
 Sets up a log file to log queries to.  The first sets up a log file for a specific connection, 
 the latter, a general log file for all connections.  The I<log-file> should be a string 
@@ -243,7 +212,7 @@ separate log files.  Return 1 if successfully opened the log file for writing, 0
 Set or retrieve the current DEFAULT package name used for placeholder variables in "INTO" clauses in 
 queries.  NOTE:  This function does NOT change the current package name used by currently opened 
 database objects, but only the default package name used when subsequent database objects are created! 
-See $db->B<package>() for changing the current package name used by an open database object. 
+See $dbh->B<package>() for changing the current package name used by an open database object. 
 IF I<package_name> is specified, the default package name is set in the program in subsequently opened 
 database objects (until B<&jdbix_package>() is called with a different package name).  
 If not specified, it returns the current package name.  The default package name is "main".  
@@ -256,35 +225,38 @@ passing the 'I<jdbix_package>' => 'I<package_name>' attribute when creating the
 
 =over 4
 
-=item I<$scalar> = $dB->B<autocommit>([ I<1 | 0> ]);
+=item I<$scalar> = $dbh->B<autocommit>([ I<1 | 0> ]);
 
 If an argument is passed, then sets the database's I<autocommit> status to on or off based on that 
 argument, if no argument is passed, it returns the current state of the database's I<autocommit> status.
 
-=item I<$scalar> = $dB->B<commit>();
+=item I<$scalar> = $dbh->B<commit>();
 
 Causes any pending queries that changed the database to be committed (unless I<autocommit> is on for 
 the database connection).  If I<autocommit> is on, it returns 1 (true).  Otherwise, it returns the 
 result of the DBI->I<commit>() call.
 
-=item $dB->B<disconnect>();
+=item $dbh->B<disconnect>();
 
 Disconnect from the database;
 
-=item I<$scalar> = $db->B<do>('I<query-string>' [, I<attrs> ]);
+=item I<$scalar> = $dbh->B<do>('I<query-string>' [, I<attrs> ]);
 
 Provides vectorized selects and inserts, updates, etc.  I<query-string> can be any valid SQL 
 query string.  Returns the number of records affected / selected.  I<attrs> is an optional 
 hash-reference that can contain one or more of the following options:
 
-B<-interpolate> => 0..3 (default 0) - 
+=over 4
+
+=item B<-interpolate> => 0..3 (default 0) - special attribute for handling the relationship between the 
+key vector(s) and the vector array(s) containing the returned results.
 
 If B<0>, then the query is just executed as-is and the 
 number of rows affected / selected is returned.  For selects based on key vectors (arrays), the 
 results are like as if 2 was specified. 
 
 If B<1>, and the query is a select, then it is 
-assumed that a 1:1 relationship exists between the array-references given in the WHERE clause 
+assumed that a 1:1 relationship exists between the vector array-references given in the WHERE clause 
 and the results returned - the query is done once in a loop for each element in the set of "keys" 
 specified by these array-references and only the first matching record for each keyset will be 
 returned.  All the arrays given by the array-references in both the WHERE clause AND the INTO 
@@ -299,31 +271,33 @@ guarenteed to be returned for EACH element in the longest key array (all key arr
 same length).  With 3, if no records match a given element in the key arrays, then no records will 
 be returned for that set of keys.
 
-B<-commit> => true | false (default false) - If I<autocommit> is off for the database connection, 
+=item B<-commit> => true | false (default false) - If I<autocommit> is off for the database connection, 
 a I<commit> will be done automatically after the query completes (if any records affected) (if TRUE), 
 no commit is done if FALSE.
 
-=item [ I<$scalar> | I<@array> = ] $db->B<do1>('I<query-string>' [, I<bind-parameter-list> ]);
+=back
+
+=item [ I<$scalar> | I<@array> = ] $dbh->B<do1>('I<query-string>' [, I<bind-parameter-list> ]);
 
 Performs a single query as-is.  
 
-Similar to $db->B<do1>(), but simpler and a I<bind-parameter-list> is allowed.  This method is the 
+Similar to $dbh->B<do1>(), but simpler and a I<bind-parameter-list> is allowed.  This method is the 
 preferred method of doing non-select queries, but can handle selects too.  The optional returned 
-results are the same as $db->B<select>() for select queries, and $db->B<do>() for other queries.
-The primary difference versus $db->B<do>() is that the query is not looped against vectors given 
+results are the same as $dbh->B<select>() for select queries, and $dbh->B<do>() for other queries.
+The primary difference versus $dbh->B<do>() is that the query is not looped against vectors given 
 in a WHERE clause, the WHERE clause must be a simple scalar set of key values, which can be bound 
 with placeholders by the I<bind-parameter-list>.  Results are not committed unless I<autocommit> is 
 turned on for the database connection.  Think of it as "do ONE query".
 
-=item I<$scalar> = $dB->B<err>();
+=item I<$scalar> = $dbh->B<err>();
 
 Returns the last error code number encountered.
 
-=item I<$scalar> = B<&jdbix_errstr>([ I<$database_object> ]);
+=item I<$scalar> = $dbh->B<errstr>();
 
 Returns the last error message text for the last error encountered.  
 
-=item I<$scalar> = $dB->B<fetchnextseq>([ I<sequencename> ]);
+=item I<$scalar> = $dbh->B<fetchnextseq>([ I<sequencename> ]);
 
 This can be called anytime and returns the next value of sequence I<sequencename>.  For Sprite and Oracle, 
 this is accomplished by doing a "SELECT <sequencename>.NEXTVAL from DUAL".  For mysql, it returns the 
@@ -336,7 +310,7 @@ emulating a "sequence".  For mysql and SQLite, the I<sequencename> can be omitte
 I<mysql_insert_id>() which is the value of the most recent autonumber field updated.  SQLite always 
 returns I<sqlite_last_insert_rowid>().
 
-=item I<$scalar> = $db->B<fetchseq>('I<keyfieldname>', [ 'I<sequencename>', [ I<tablename>' ] ]);
+=item I<$scalar> = $dbh->B<fetchseq>('I<keyfieldname>', [ 'I<sequencename>', [ I<tablename>' ] ]);
 
 This is called after an insert and should return the value of the last sequence specified in that 
 insert (used to get the key of the last record inserted) when using sequences or the autonumbering 
@@ -362,34 +336,34 @@ B<fetchseq>() which table to grab the most recent autonumber / sequence field sp
 I<keyfieldname> from.  It is ignored for supported databases and defaults to the last table to which 
 an insert or update involving a sequence or autonumber field was done.
 
-=item I<$scalar> = $dB->B<package>([ I<package_name> ]);
+=item I<$scalar> = $dbh->B<package>([ I<package_name> ]);
 
 Set or retrieve the current package name used for placeholder variables in "INTO" clauses in queries.  
 IF I<package_name> is specified, the default package for all such variables from that point on in 
 the program (until B<&jdbix_package>() is called with a different package name) are assumed to be of 
 that package.  If not specified, it returns the current package name.  The default package name 
 is "main".  NOTE:  The current I<package_name> can also be set for a database when opened by 
-passing the 'I<jdbix_package>' => 'I<package_name>' attribute when creating the database object.
+passing the 'I<-jdbix_package>' => 'I<package_name>' attribute when creating the database object.
 
-=item I<$scalar> = $dB->B<rollback>();
+=item I<$scalar> = $dbh->B<rollback>();
 
 Causes any pending queries that changed the database to be rolled back (unless I<autocommit> is on for 
 the database connection).  If I<autocommit> is on, it returns 1 (true).  Otherwise, it returns the 
 result of the DBI->I<rollback>() call.
 
-=item $dB->B<select>('I<query-string>' [, I<bind-parameter-list>]);
+=item $dbh->B<select>('I<query-string>' [, I<bind-parameter-list>]);
 
 Perform a selection query on the database.  The I<query-string> can be a standard SQL query 
 string, but may contain traditional SQL placeholders ("?") or special JDBIx placeholders 
 in an "INTO" clause representing corresponding Perl variables to receive the respective field data.  
 For example:
 
-[ I<$scalar> | I<@array> = ] $dB->B<select>('select field1, field2, field3 into :f1, :f2, :f3 where keyfield = ?', 'foo');
+[ I<$scalar> | I<@array> = ] $dbh->B<select>('select field1, field2, field3 into :f1, :f2, :f3 where keyfield = ?', 'foo');
 
-This would do a B<prepare>, a B<execute>, and B<fetch> functions and create / reset three 
+This would do a B<prepare>(), an B<execute>(), and B<fetch>() functions, and create / reset three 
 scalars ($f1, $f2, and $f3) set to the first values returned for the respective fields, and 
 three arrays (@f1, @f2, and @f3), each containing a list of all the values returned for their 
-respective columns.  NOTE: These are I<package> variables, NOT "my" variables.  The I<package> is 
+respective columns.  NOTE:  These are I<package> variables, NOT "my" variables.  The I<package> is 
 the current package (or main) or the one specified by the B<dbix_package> attribute when the 
 database object was created.
 
@@ -405,7 +379,7 @@ returned, then it is ().  If I<$scalar> is given, then it is the number of recor
 
 =over 4
 
-=item I<$scalar> = $dB->B<opencsr>(I<query-string> [, I<execute_flag> ]);
+=item I<$scalar> = $dbh->B<opencsr>(I<query-string> [, I<execute_flag> ]);
 
 Opens a "cursor" (does a I<prepare>()) on the query specified by I<query-string> and returns a "cursor" 
 object which can be used ...
@@ -455,7 +429,7 @@ Closes the cursor.
 
 =head1 SEE ALSO
 
-DBI(3), perl(1)
+L<DBI>, L<perl(1)>
 
 =cut
 
@@ -466,7 +440,7 @@ package JDBIx;
 use FileHandle;
 use DBI;
 use vars qw(@ISA @EXPORT $VERSION);
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 require Exporter;
 
@@ -536,13 +510,11 @@ sub new
 	if ($connectstr =~ s/^\s*(?:connect\=|\=)//i)
 	{
 #		$self->{dbtype} = $1  if ($connectstr =~ /dbi\:${dbi_proxy}(\w+):/);
-print "-1: cs=$connectstr= proxy=$dbi_proxy=\n";
 #x		if ($connectstr =~ /dbi\:${dbi_proxy}([^\:]+)\:(\w*)/)
 		if ($connectstr =~ /dbi\:proxy\:([^\:]+)\:/i)
 		{
 			$dbi_proxy = $1;
 			($self->{proxy} = $dbi_proxy) =~ s/\;dsn=DBI$//i;
-print "-2: dbi_proxy=$dbi_proxy= proxy=".$self->{proxy}."= cs=$connectstr=\n";
 			if ($connectstr =~ /dbi\:proxy\:${dbi_proxy}\:([^\:]+)\:(\w*)/i)
 			{
 				$self->{dbtype} = $1  if ($1);
@@ -559,7 +531,6 @@ print "-2: dbi_proxy=$dbi_proxy= proxy=".$self->{proxy}."= cs=$connectstr=\n";
 				$self->{dbtype} = $1  if ($1);
 				$self->{dbname} = $2  if ($2);
 			}
-print "-3: type:=$1=\n";
 		}
 		$dbi_err = \$DBI::err;
 		$dbi_errstr = \$DBI::errstr;
@@ -705,17 +676,16 @@ sub jdbix_package
 
 sub disconnect
 {
-	my $dB = shift;
-	return undef  unless ($dB->{DBI});
-	my $res = $dB->{DBI}->disconnect;
+	return undef  unless ($_[0]->{DBI});
+	my $res = $_[0]->{DBI}->disconnect;
 	if ($self->{logfid})
 	{
 		$self->{logfh}->close;
 		$self->{logfid} = 0;
 		undef $self->{logfh};
 	}
-	$dB->{DBI} = undef;
-	undef $dB;
+	$_[0]->{DBI} = undef;
+	undef $_[0];
 	return $res;
 }
 
@@ -835,7 +805,7 @@ sub do
 {
 	my ($self, $sqlstr, $ophref) = @_;
 
-#### WARNING:  DO *NOT* USE SINGLE-QUOTES AROUND ANY /:PARAMETERS !!!!!!!!!
+#### WARNING:  DO *NOT* USE SINGLE-QUOTES AROUND ANY :PARAMETERS !!!!!!!!!
 #### (IT DON'T WORK!)
 
 	my ($interpolate) = $ophref->{-interpolate} || $ophref;
@@ -1230,8 +1200,9 @@ II:
 			{
 				my $ordbyclause = $1;
 				my $sortavailable;
-				eval {require 'sort_elements.pl' and $sortavailable = 1;};
-				if ($sortavailable)
+#s				eval {require 'sort_elements.pl' and $sortavailable = 1;};
+#s				if ($sortavailable)
+				unless (1)
 				{
 					my @sortfields = split(/\,/o, $ordbyclause);
 					my @sortorders = ();
